==> haskell-numinstances-1.4-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-numinstances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 NumInstances
version:              1.4
visibility:           public
id:                   NumInstances-1.4-KqRAOAeLv9H1q3OPA3mDpV
key:                  NumInstances-1.4-KqRAOAeLv9H1q3OPA3mDpV
license:              BSD-3-Clause
maintainer:           conal@conal.net
author:               Conal Elliott
homepage:             https://github.com/conal/NumInstances
synopsis:             Instances of numeric classes for functions and tuples
description:
    Instances of numeric classes for functions and tuples.
    Import "Data.NumInstances" to get all the instances.
    If you want only function or only tuple instances, import
    "Data.NumInstances.Function" or "Data.NumInstances.Tuple".

category:             Data
abi:                  b97b2e7e2995a826c371bd9a1c535782
exposed:              True
exposed-modules:
    Data.NumInstances Data.NumInstances.Function
    Data.NumInstances.Tuple

hidden-modules:
    Data.NumInstances.Util Data.NumInstances.PreRequisites

import-dirs:          /usr/lib/ghc-9.2.8/site-local/NumInstances-1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/NumInstances-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numinstances
hs-libraries:         HSNumInstances-1.4-KqRAOAeLv9H1q3OPA3mDpV
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-numinstances/html/NumInstances.haddock

haddock-html:         /usr/share/doc/haskell-numinstances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-numinstances-1.4-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-numinstances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 NumInstances
version:              1.4
visibility:           public
id:                   NumInstances-1.4-4OncN3WniO73xybRJJuGAa
key:                  NumInstances-1.4-4OncN3WniO73xybRJJuGAa
license:              BSD-3-Clause
maintainer:           conal@conal.net
author:               Conal Elliott
homepage:             https://github.com/conal/NumInstances
synopsis:             Instances of numeric classes for functions and tuples
description:
    Instances of numeric classes for functions and tuples.
    Import "Data.NumInstances" to get all the instances.
    If you want only function or only tuple instances, import
    "Data.NumInstances.Function" or "Data.NumInstances.Tuple".

category:             Data
abi:                  6953400d52191f9517634213f8adbef5
exposed:              True
exposed-modules:
    Data.NumInstances Data.NumInstances.Function
    Data.NumInstances.Tuple

hidden-modules:
    Data.NumInstances.Util Data.NumInstances.PreRequisites

import-dirs:          /usr/lib/ghc-9.4.8/site-local/NumInstances-1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/NumInstances-1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/NumInstances-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numinstances
hs-libraries:         HSNumInstances-1.4-4OncN3WniO73xybRJJuGAa
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-numinstances/html/NumInstances.haddock

haddock-html:         /usr/share/doc/haskell-numinstances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
